@@ -1,6 +1,5 @@
 from tkinter import simpledialog
 from tkinter.ttk import Notebook
-from warnings import showwarning
 from ScrollText import *
 from tkinter import *
 from tkinter import messagebox,font
@@ -935,7 +934,7 @@ class TerminalWindow(ScrollText):
             self.lvProperties.delete(item)
         for k in sorted(self.proplist.keys()):
             v=self.proplist[k]
-            (obj,prop)=k.split(".")
+            (obj,prop)=k.split(".", 1)
             name=self.namelist[obj] if obj in self.namelist else obj
             self.lvProperties.insert("",END,text=obj, values=(name,prop,v))
         self.fitListContents(self.lvProperties)
